@@ -13,7 +13,12 @@ from ._math_tensor import (
     sin,
     cos,
     tan,
+    sinh,
+    cosh,
     tanh,
+    exp,
+    log,
+    log10,
     dot,
     ddot,
     trace,
@@ -22,4 +27,7 @@ from ._math_tensor import (
     sqrt,
     einsum,
     matmul,
+    diagonal,
+    ravel,
 )
+from . import _math_array as array
